pub struct Graft {
pub local: VolumeId,
pub remote: VolumeId,
pub sync: Option<SyncPoint>,
pub pending_commit: Option<PendingCommit>,
}Fields
local: VolumeIdThe local Volume backing this Graft
remote: VolumeIdThe remote Volume backing this Graft.
sync: Option<SyncPoint>Metadata keeping track of which portion of the local and remote volume this Graft cares about.
pending_commit: Option<PendingCommit>Presence of the pending_commit field means that the Push operation is in
the process of committing to the remote. If no such Push job is currently
running (i.e. it was interrupted), this field must be used to resume or
abort the commit process.
Implementations
Sourceimpl Graft
impl Graft
pub fn new( local: VolumeId, remote: VolumeId, sync: Option<SyncPoint>, pending_commit: Option<PendingCommit>, ) -> Self
pub fn with_sync(self, sync: Option<SyncPoint>) -> Self
pub fn sync(&self) -> Option<&SyncPoint>
pub fn with_pending_commit(self, pending_commit: Option<PendingCommit>) -> Self
pub fn pending_commit(&self) -> Option<&PendingCommit>
pub fn local_watermark(&self) -> Option<LSN>
pub fn remote_commit(&self) -> Option<LSN>
pub fn local_changes(&self, head: Option<LSN>) -> Option<RangeInclusive<LSN>>
pub fn remote_changes(&self, head: Option<LSN>) -> Option<RangeInclusive<LSN>>
pub fn status( &self, latest_local: Option<LSN>, latest_remote: Option<LSN>, ) -> GraftStatus