ReadWriteGuard

Struct ReadWriteGuard 

pub struct ReadWriteGuard<'a> { /* private fields */ }

Implementations

Source

impl<'a> ReadWriteGuard<'a>

pub fn tag_replace( &self, tag: &str, graft: VolumeId, ) -> Result<Option<VolumeId>, FjallStorageErr>

pub fn graft_open( self, graft: Option<VolumeId>, remote: Option<VolumeId>, ) -> Result<Graft, FjallStorageErr>

opens a graft. if either the graft’s VolumeId or the remote’s VolumeId are missing, they will be randomly generated. If the graft already exists, this function will fail if its remote doesn’t match.

pub fn commit( self, graft: &VolumeId, snapshot: Snapshot, page_count: PageCount, segment: SegmentIdx, ) -> Result<Snapshot, FjallStorageErr>

Attempt to execute a local commit to the specified Graft’s local volume.

Returns the resulting VolumeRef on success

pub fn remote_commit_prepare( self, graft: &VolumeId, pending_commit: PendingCommit, ) -> Result<(), FjallStorageErr>

Verify we are ready to make a remote commit and update the graft with a PendingCommit

pub fn remote_commit_success( self, graft: &VolumeId, remote_commit: Commit, ) -> Result<(), FjallStorageErr>

Finish the remote commit process by writing out an updated graft and recording the remote commit locally

pub fn drop_pending_commit( self, graft: &VolumeId, ) -> Result<(), FjallStorageErr>

Drop a pending commit without applying it. This should only be called after receiving a rejection from the remote.

pub fn sync_remote_to_local( self, graft: VolumeId, ) -> Result<(), FjallStorageErr>