pub struct LeapOracle { /* private fields */ }Expand description
LeapOracle is an implementation of the algorithm described by the paper
“Effectively Prefetching Remote Memory with Leap”. It provides an Oracle
that attempts to predict future page requests based on trends found in
recent history.
Hasan Al Maruf and Mosharaf Chowdhury. (2020). Effectively Prefetching Remote Memory with Leap. In Proceedings of the 2020 USENIX Conference on Usenix Annual Technical Conference (USENIX ATC’20), Article 58, 843–857. USENIX Association, USA.