pub struct NoopOracle;Trait Implementations
Sourceimpl Oracle for NoopOracle
impl Oracle for NoopOracle
Sourcefn observe_cache_hit(&mut self, _pageidx: PageIdx)
fn observe_cache_hit(&mut self, _pageidx: PageIdx)
observe_cache_hit is called whenever Graft satisfies a page read from
it’s local cache. This function is not called on a cache miss.Sourcefn predict_next(&mut self, _pageidx: PageIdx) -> impl Iterator<Item = PageIdx>
fn predict_next(&mut self, _pageidx: PageIdx) -> impl Iterator<Item = PageIdx>
predict_next is called when Graft has a cache miss, and can be used to
hint that Graft should fetch additional pages along with the requested
page. The returned iterator should be empty if no additional pages
should be fetched, and it does not need to include the requested page.Auto Trait Implementations
impl Freeze for NoopOracle
impl RefUnwindSafe for NoopOracle
impl Send for NoopOracle
impl Sync for NoopOracle
impl Unpin for NoopOracle
impl UnwindSafe for NoopOracle