Remote

Struct Remote 

pub struct Remote { /* private fields */ }

Implementations

Source

impl Remote

pub fn with_config(config: RemoteConfig) -> Result<Self>

pub async fn get_checkpoints( &self, vid: &VolumeId, etag: Option<String>, ) -> Result<CachedCheckpoints>

Fetches checkpoints for the specified volume. If etag is not None then this method will return a not modified error.

pub fn stream_commits_ordered<I: IntoIterator<Item = LSN>>( &self, vid: &VolumeId, lsns: I, ) -> impl Stream<Item = Result<Commit>>

Streams commits by LSN in the same order as the input iterator. Stops fetching commits as soon as we receive a NotFound error from the remote, thus even if lsns contains every LSN we will stop loading commits as soon as we reach the end of the log.

pub async fn get_commit( &self, vid: &VolumeId, lsn: LSN, ) -> Result<Option<Commit>>

Fetches a single commit, returning None if the commit is not found.

pub async fn put_commit(&self, commit: &Commit) -> Result<()>

Atomically write a commit to the remote, returning RemoteErr::ObjectStore(Error::AlreadyExists) on a collision

pub async fn put_segment<I: IntoIterator<Item = Bytes>>( &self, sid: &SegmentId, chunks: I, ) -> Result<()>

Uploads a segment to this Remote

pub async fn get_segment_range( &self, sid: &SegmentId, bytes: &Range<usize>, ) -> Result<Bytes>

Reads a byte range of a segment