Runtime

Struct Runtime 

pub struct Runtime { /* private fields */ }

Implementations

Source

impl Runtime

pub fn new( tokio_rt: Handle, remote: Arc<Remote>, storage: Arc<FjallStorage>, autosync: Option<Duration>, ) -> Runtime

Create a Graft Runtime wrapping the provided Tokio runtime handle.

Source

impl Runtime

pub fn tag_iter( &self, ) -> impl Iterator<Item = Result<(ByteString, VolumeId), KernelErr>>

pub fn tag_exists(&self, name: &str) -> Result<bool, KernelErr>

pub fn tag_get(&self, tag: &str) -> Result<Option<VolumeId>, KernelErr>

pub fn tag_replace( &self, tag: &str, graft: VolumeId, ) -> Result<Option<VolumeId>, KernelErr>

retrieves the VolumeId for a tag, replacing it with the provided graft

pub fn tag_delete(&self, tag: &str) -> Result<(), KernelErr>

Source

impl Runtime

pub fn graft_iter(&self) -> impl Iterator<Item = Result<Graft, KernelErr>>

pub fn graft_exists(&self, graft: &VolumeId) -> Result<bool, KernelErr>

pub fn graft_open( &self, graft: Option<VolumeId>, remote: Option<VolumeId>, ) -> Result<Graft, KernelErr>

opens a graft. if either the graft’s VolumeId or the remote’s VolumeId are missing, they will be randomly generated. If the graft already exists, this function will fail if its remote doesn’t match.

pub fn graft_from_snapshot( &self, snapshot: &Snapshot, ) -> Result<Graft, KernelErr>

creates a new graft by forking an existing snapshot

pub fn graft_get(&self, graft: &VolumeId) -> Result<Graft, KernelErr>

retrieves an existing graft. returns LogicalErr::GraftNotFound if missing

pub fn graft_delete(&self, graft: &VolumeId) -> Result<(), KernelErr>

removes a graft but leaves the underlying volumes in place

pub fn graft_pull(&self, graft: VolumeId) -> Result<(), KernelErr>

fetches the latest changes to the remote and then pulls them into the graft

pub fn graft_push(&self, graft: VolumeId) -> Result<(), KernelErr>

pub fn graft_status(&self, graft: &VolumeId) -> Result<GraftStatus, KernelErr>

pub fn graft_snapshot(&self, graft: &VolumeId) -> Result<Snapshot, KernelErr>

pub fn graft_reader(&self, graft: VolumeId) -> Result<GraftReader, KernelErr>

pub fn graft_writer(&self, graft: VolumeId) -> Result<GraftWriter, KernelErr>

Source

impl Runtime

pub fn fetch_volume( &self, vid: VolumeId, max_lsn: Option<LSN>, ) -> Result<(), KernelErr>

Source

impl Runtime

pub fn snapshot_pages( &self, snapshot: &Snapshot, ) -> Result<PageCount, KernelErr>

returns the total number of pages in the snapshot

pub fn snapshot_is_latest( &self, graft: &VolumeId, snapshot: &Snapshot, ) -> Result<bool, KernelErr>

pub fn snapshot_checksum( &self, snapshot: &Snapshot, ) -> Result<Checksum, KernelErr>

returns the checksum of the snapshot

pub fn snapshot_missing_pages( &self, snapshot: &Snapshot, ) -> Result<PageSet, KernelErr>

pub fn snapshot_hydrate(&self, snapshot: Snapshot) -> Result<(), KernelErr>