setup_graft

Function setup_graft 

pub fn setup_graft(config: GraftConfig) -> Result<Runtime, InitErr>
An opinionated but simple setup method. Sets up a Tokio current thread runtime on a background thread. Configures Graft using the provided config.

For more complex setups such as custom Tokio runtimes, it’s recommended to setup the Graft Runtime manually instead.