pub struct PendingCommit {
pub local: LSN,
pub commit: LSN,
pub commit_hash: CommitHash,
}Fields
local: LSNThe LSN we are syncing from the local Volume
commit: LSNThe LSN we are creating in the remote Volume
commit_hash: CommitHashThe pending remote commit hash. This is used to determine whether or not the commit has landed in the remote, in the case that we are interrupted while attempting to push.